<h1>Create a dynamic PDF!</h1>
<div>
	<% form_tag(rml_sample_path, :method => "post") do %>
		<%= label_tag(:name, "Enter your name:") %>
		<%= text_field_tag(:name) %>
		<%= submit_tag("Make PDF") %>
	<% end %>
</div>
